package cn.com.ty.lift.enterprise.custom.controller;

import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyContact;
import cn.com.ty.lift.enterprise.custom.service.impl.PropertyContactServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.List;

@RestController
@RequestMapping("/property-contact")
@AllArgsConstructor
/**
 * @author wang-hai-cheng
 * @date 2019/11/27
 * @description
 * (甲方联系人)客户联系人表 前端控制器
 */
public class PropertyContactController {
    private final PropertyContactServiceImpl propertyContactService;

    @GetMapping("/list")
    /**
         * @description 根据客户id分页查它的联系人
         * @date 2019/11/29 8:21
         * @param [ppCompanyId, userId, pageNum, pageSize]
         * @return cn.com.xwy.boot.web.dto.RestResponse
         */
    public RestResponse propertyContacts(@RequestParam Long ppCompanyId, @RequestParam Long userId, Integer pageNum, Integer pageSize) {
        Page<PropertyContact> page = new Page<>(pageNum, pageSize);
        List<PropertyContact> records = propertyContactService.page(page, new QueryWrapper<PropertyContact>()
                .select("id","pp_company_id","name","dept","job","telephone","gender","age","remarks","status","user_id")
                .eq("pp_company_id", ppCompanyId).eq("user_id",userId)).getRecords();
        if (!records.isEmpty()) {
            return RestResponse.ok(records,"1","查询成功");
        } else {
            return RestResponse.ok(null, "9","无数据");
        }
    }

    @PostMapping("/add")
    /**
     * @description 根据客户id，新增联系人
     * @date 2019/11/27 11:23
     * @param [propertyContact]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse add(@RequestBody PropertyContact propertyContact) {
        propertyContact.setCreateDate(LocalDateTime.now());
        System.out.println(propertyContact.getPpCompanyId());
        if (propertyContactService.save(propertyContact)) {
            return RestResponse.ok(null, "1","新增成功");
        } else {
            return RestResponse.ok(null, "0","新增失败");
        }
    }

    @PostMapping("/update")
    /**
     * @description 编辑联系人
     * @date 2019/11/27 11:26
     * @param [propertyContact]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse update(@RequestBody PropertyContact propertyContact) {
        if (propertyContactService.updateById(propertyContact)) {
            return RestResponse.ok(null, "1","更新成功");
        } else {
            return RestResponse.ok(null,"0", "更新失败");
        }
    }

    @GetMapping("/delete/{id}")
    /**
     * @description 删除联系人
     * @date 2019/11/27 11:28
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse delete(@PathVariable Long id) {
        PropertyContact propertyContact = new PropertyContact();
        propertyContact.setStatus(0);
        if (propertyContactService.update(propertyContact,new QueryWrapper<PropertyContact>().eq("id",id))) {
            return RestResponse.ok(null, "删除成功");
        } else {
            return RestResponse.ok(null, "删除失败");
        }
    }
}