package cn.com.ty.lift.enterprise.custom.service.impl;

import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyCompany;
import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyContact;
import cn.com.ty.lift.enterprise.custom.dao.mapper.PropertyCompanyMapper;
import cn.com.ty.lift.enterprise.custom.dao.mapper.PropertyContactMapper;
import cn.com.ty.lift.enterprise.custom.service.PropertyCompanyService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * (甲方公司)客户表 服务实现类
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-11-11
 */
@Service
@Transactional
@AllArgsConstructor
public class PropertyCompanyServiceImpl extends ServiceImpl<PropertyCompanyMapper, PropertyCompany> implements PropertyCompanyService {
    private final PropertyContactMapper contactMapper;

    public RestResponse savePropertyCompany(@RequestBody PropertyCompany propertyCompany) {
        if (null == this.getOne(new QueryWrapper<PropertyCompany>().eq("name", propertyCompany.getName()))) {
            if (this.save(propertyCompany)) {
                return RestResponse.ok(null, "1", "新增客户成功");
            } else {
                return RestResponse.ok(null, "0", "新增客户失败");
            }
        } else {
            return RestResponse.ok(null, "0", "客户已存在");
        }
    }

    public String delete(Long id) {
        //维保电梯大于0
        if (this.getMaintenanceLiftNum() > 0) {
            //就不删除
            return "维保电梯大于0，无法删除";
        } else {
            //如果维保电梯小于等于0，逻辑删除
            PropertyCompany one = this.getOne(new QueryWrapper<PropertyCompany>().eq("id", id));
            if (null != one) {
                one.setStatus(0);
                this.updateById(one);
                this.deleteForContact(id);
                return "删除成功";
            } else {
                return "删除失败";
            }
        }
    }

    public int deleteForContact(Long id) {
        PropertyContact propertyContact = new PropertyContact();
        propertyContact.setStatus(0);
        return contactMapper.update(propertyContact, new QueryWrapper<PropertyContact>().eq("pp_company_id", id));
    }

    private int getMaintenanceLiftNum() {
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        //查询维保电梯数
        return 888;
    }

    /**
     * @param
     * @return
     * @description 根据id分页查询客户
     * @date 2019/12/2 10:15
     */
    public RestResponse propertyCompanies(Long mtCompanyId, Integer pageNum, Integer pageSize) {
        Page<PropertyCompany> page = new Page<>(pageNum, pageSize);
        IPage<Map<String, Object>> records = this.pageMaps(page, new QueryWrapper<PropertyCompany>()
                .select("id", "code", "name", "address", "telephone")
                .eq("mt_company_id", mtCompanyId));
        records.getRecords().forEach(record -> {
            record.put("maintenanceLiftNum", this.getMaintenanceLiftNum());
        });
        return RestResponse.ok(records, "查询成功");
    }

    /**
     * @param
     * @return
     * @description 根据rowName(字段名)，分页查询
     * @date 2019/12/2 10:16
     */
    public RestResponse propertyCompaniesFromRowName(Long mtCompanyId, Integer pageNum, Integer pageSize, String rowName, Object rowValue) {
        Page<PropertyCompany> page = new Page<>(pageNum, pageSize);
        IPage<Map<String, Object>> records = this.pageMaps(page, new QueryWrapper<PropertyCompany>()
                .select("id", "code", "name", "address", "telephone").like(rowName, rowValue)
                .eq("mt_company_id", mtCompanyId));
        records.getRecords().forEach(record -> {
            record.put("maintenanceLiftNum", this.getMaintenanceLiftNum());
        });
        return RestResponse.ok(records, "1", "查询成功");
    }

    public RestResponse propertyCompaniesForCondition(HashMap map) {
        String name = (String) map.get("name");
        String address = (String) map.get("address");
        String telephone = (String) map.get("telephone");
        boolean nameFlag = name != null;
        boolean addressFlag = address != null;
        boolean telephoneFlag = telephone != null;

        Page<PropertyCompany> page = new Page<>((Integer) map.get("pageNum"), (Integer) map.get("pageSize"));
        IPage<Map<String, Object>> records = this
                .pageMaps(page, new QueryWrapper<PropertyCompany>()
                        .select("id", "code", "name", "address", "telephone")
                        .eq("mt_company_id", map.get("mtCompanyId"))
                        .like(nameFlag, "name", name).like(addressFlag, "address", address).like(telephoneFlag, "telephone", telephone));
        if (!records.getRecords().isEmpty()) {
            records.getRecords().forEach(record -> {
                record.put("maintenanceLiftNum", this.getMaintenanceLiftNum());
            });
            return RestResponse.ok(records, "1", "查询成功");
        } else {
            return RestResponse.ok(null, "9", "无数据");
        }
    }
}