package cn.com.ty.lift.manager.library.service;

import cn.com.ty.lift.common.base.ExportRequest;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.common.export.ExportUtils;
import cn.com.ty.lift.manager.framework.util.MessageUtils;
import cn.com.ty.lift.manager.library.dao.entity.Lift;
import cn.com.ty.lift.manager.library.dao.entity.LiftExtension;
import cn.com.ty.lift.manager.library.dao.mapper.LiftExtensionMapper;
import cn.com.ty.lift.manager.library.dao.mapper.LiftMapper;
import cn.com.ty.lift.manager.library.dao.entity.model.LiftRequest;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author bieao
 * @date 2019/11/27
 * @description 电梯档案业务层
 */
@Service
public class LibraryService {

    @Resource
    private LiftMapper liftMapper;

    @Resource
    private LiftExtensionMapper liftExtensionMapper;

    private Map<String, String> paramMap = new HashMap<String, String>() {{
        put("liftCode", "电梯号");
        put("registrationCode", "注册代码");
        put("liftBrand", "电梯品牌");
        put("liftType", "电梯类型");
        put("devicePosition", "设备使用地点");
    }};

    /**
     * @param request 电梯列表查询条件
     * @return RestResponse 结果集
     * @description 条件查询电梯档案列表
     * @date 2019/11/27 2:10 PM
     */
    public RestResponse<IPage<Lift>> list(LiftRequest request) {
        IPage<Lift> page = new Page<>(request.getPageNum(), request.getPageSize());
        List<Lift> lifts = liftMapper.findByCondition(page, request);
        if (lifts.isEmpty()) {
            page.setRecords(new ArrayList<>());
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.data.empty"));
        }
        page.setRecords(lifts);
        return RestResponse.ok(page, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param lift 电梯
     * @return 电梯扩展实体
     * @description 初始化电梯扩展实体
     * @date 2019/12/3 3:25 PM
     */
    private LiftExtension init(Lift lift) {
        LiftExtension extension = new LiftExtension();
        extension.setId(lift.getId());
        extension.setAnnualInspectionDate(lift.getAnnualInspectionDate());
        extension.setWorkerId(lift.getWorkerId());
        return extension;
    }

    /**
     * @param lift 新增项目数据项
     * @return RestResponse 状态码和返回消息
     * @description 新增电梯
     * @date 2019/11/27 2:22 PM
     */
    @Transactional
    public RestResponse add(Lift lift) {
        Long id = liftMapper.insertSelective(lift);
        if (id != null) {
            LiftExtension extension = init(lift);
            Integer result = liftExtensionMapper.insertSelective(extension);
            if (result > 0) {
                return RestResponse.ok(result, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.add.success"));
            }
        }
        return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.add.fail"));
    }

    /**
     * @param lift 修改电梯数据项
     * @return RestResponse 状态码和返回消息
     * @description 修改电梯
     * @date 2019/11/27 2:22 PM
     */
    public RestResponse modify(Lift lift) {
        Integer result = liftMapper.updateByPrimaryKeySelective(lift);
        if (result > 0) {
            return RestResponse.ok(result, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
        }
        return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
    }

    /**
     * @param request 导出电梯数据列表
     * @return RestResponse 状态码和返回消息
     * @description 导出电梯
     * @date 2019/11/27 2:22 PM
     */
    public void export(ExportRequest request) {
        List<Lift> liftList = liftMapper.selectBatchIds(request.getIds());
        ExportUtils utils = new ExportUtils();
        utils.export(liftList, paramMap, request.getExportPath());
    }
}
