package cn.com.ty.lift.quan.news.controller;

import cn.com.ty.lift.quan.news.dao.entity.QuanNews;
import cn.com.ty.lift.quan.news.service.impl.QuanNewsServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;


/**
 * <p>
 * 电梯圈新闻公告 前端控制器
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-12-02
 */
@RestController
@AllArgsConstructor
@RequestMapping("/quan-news")
public class QuanNewsController {
    private final QuanNewsServiceImpl quanNewsService;

    @GetMapping("/list")
    /**
     * @description 分页展示置顶新闻+普通新闻
     * @date 2019/12/2 15:39
     * @param [页码, 页大小]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse list(@RequestParam int pageNum, @RequestParam int pageSize, @RequestParam int haveTops) {
        return quanNewsService.news(pageNum, pageSize, haveTops);
    }

    @PostMapping("/top")
    /**
     * @description 置顶
     * @date 2019/12/2 15:40
     * @param [新闻id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse top(@RequestParam Integer id) {
        return quanNewsService.top(id);
    }

    @PostMapping("/top/cancel")
    /**
     * @description 取消置顶
     * @date 2019/12/3 13:28
     * @param [新闻id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse cancelTop(@RequestParam Integer id) {
        return quanNewsService.cancelTop(id);
    }

    @GetMapping("/{id}")
    /**
     * @description 根据id获取新闻
     * @date 2019/12/2 15:48
     * @param [新闻id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse news(@PathVariable int id) {
        QuanNews byId = quanNewsService.getById(id);
        if (null != byId) {
            return RestResponse.ok(byId, "1", "查询成功");
        } else {
            return RestResponse.ok(null, "9", "无数据");
        }
    }

    @PostMapping("/add")
    /**
     * @description 新增新闻
     * @date 2019/12/2 15:48
     * @param [新闻标题, 新闻内容, 视频文件, 发布人id]
     * @return org.springframework.http.ResponseEntity
     */
    public RestResponse add(@RequestParam String title, @RequestParam String content, @RequestParam MultipartFile videoFile, @RequestParam Integer isTop, @RequestParam Long releaseId, @RequestParam String releaseUser) {
        QuanNews quanNews = new QuanNews();
        quanNews.setTitle(title).setContent(content).setReleaseId(releaseId).setReleaseUser(releaseUser);
        return quanNewsService.addNew(quanNews,videoFile, isTop);
    }

    @PostMapping("/update")
    /**
     * @description 根据id更新新闻信息
     * @date 2019/12/2 15:49
     * @param [新闻id, 新闻标题, 新闻内容]
     * @return org.springframework.http.ResponseEntity
     */
    public RestResponse updateNews(@RequestBody QuanNews quanNews) {
        return quanNewsService.updateNews(quanNews.getId(), quanNews.getTitle(), quanNews.getContent());
    }

    @PostMapping("/delete")
    /**
     * @description 根据id删除新闻
     * @date 2019/12/2 15:49
     * @param [新闻id]
     * @return org.springframework.http.ResponseEntity
     */
    public RestResponse delete(@RequestParam int id) {
        return quanNewsService.delete(id);
    }
}