package cn.com.ty.lift.system.user.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.user.dao.entity.CompanyMenu;
import cn.com.ty.lift.system.user.dao.entity.Menu;
import cn.com.ty.lift.system.user.dao.entity.model.MenuRequest;
import cn.com.ty.lift.system.user.dao.mapper.MenuMapper;
import cn.com.ty.lift.system.user.service.ICompanyMenuService;
import cn.com.ty.lift.system.user.service.IMenuService;
import cn.com.ty.lift.system.user.tree.TreeUtil;
import cn.com.ty.lift.system.utils.ProjectUtils;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author huangyuan
 * @date 2019-12-01
 * @description 菜单接口实现类
 */
@Service
public class MenuService extends ServiceImpl<MenuMapper, Menu> implements IMenuService {

    @Autowired
    private MenuMapper menuMapper;

    @Autowired
    private ICompanyMenuService companyMenuService;

    @Override
    public List<Menu> getByRoleId(Long roleId) {
        return menuMapper.getByRoleId(roleId);
    }

    @Override
    public String menuToUrl(List<Menu> menuList) {
        //将菜单转化为菜单树
        List<Menu> menuTree = TreeUtil.listToTree(menuList, ApiConstants.MENU_PARENT_ATTR, ApiConstants.ROOT_MENU_PARENT_ID, "id");
        StringBuilder sb = new StringBuilder();
        //递归组合菜单路径
        menuTreeToUrl(menuTree, sb, "");
        return sb.toString();
    }

    @Override
    public RestResponse all() {
        return RestResponse.ok(this.list(), ApiConstants.RESULT_SUCCESS, "获取所有菜单信息");
    }

    @Override
    public RestResponse list(MenuRequest menuRequest) {
        List<Menu> menuList = this.list(new QueryWrapper<Menu>().eq("company_id", menuRequest.getCompanyId()));
        return RestResponse.ok(menuList, ApiConstants.RESULT_SUCCESS, "获取企业所有菜单信息");
    }

    @Override
    public RestResponse companyMenu(MenuRequest menuRequest) {
        Long companyId = menuRequest.getCompanyId();
        //获取菜单id列表
        List<Long> menuIdList = ProjectUtils.getLongIdFromIds(menuRequest.getMenuIds());
        List<CompanyMenu> needSaveCompanyMenuList = new ArrayList<>();
        if (menuIdList != null && menuIdList.size() > 0) {
            for(Long menuId:menuIdList){
                CompanyMenu companyMenu = new CompanyMenu();
                companyMenu.setCompanyId(companyId);
                companyMenu.setMenuId(menuId);
                needSaveCompanyMenuList.add(companyMenu);
            }
        }
        //保存公司菜单关联关系
        if(needSaveCompanyMenuList.size() > 0){
            companyMenuService.saveBatch(needSaveCompanyMenuList);
        }
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "分配菜单成功");
    }

    /**
     * @param menuTree 菜单树，
     * @param sb       路径StringBuilder对象
     * @param url      请求路径
     * @return
     * @description 菜单树转化为路径字符串
     * @date 2019/11/27 10:03 AM
     */
    private void menuTreeToUrl(List<Menu> menuTree, StringBuilder sb, String url) {
        if (menuTree != null && menuTree.size() > 0) {
            for (Menu menu : menuTree) {
                if (StringUtils.isNotBlank(menu.getUrl())) {
                    url = url + menu.getUrl();
                }
                menuTreeToUrl(menu.getChildren(), sb, url);
            }
        }
        sb.append(url + ",");
    }
}
